summaryrefslogtreecommitdiff
path: root/android_icu4j
diff options
context:
space:
mode:
authorVictor Chang <vichang@google.com>2021-03-25 12:41:10 +0000
committerVictor Chang <vichang@google.com>2021-03-25 12:49:46 +0000
commit13855efd8a7d5e4de74f8a55e5083fb8d4d5a2bf (patch)
treed753cdfb9b33a3d0af3aeef0d56bdd50396491ee /android_icu4j
parent96ae031e8caa2c193cb9c34aa93d2617024db207 (diff)
downloadicu-13855efd8a7d5e4de74f8a55e5083fb8d4d5a2bf.tar.gz
Improve the documentation about IntraCoreApi
Bug: 183477238 Test: m droid Change-Id: I5bf90d3087edc44a8757277cd10e424602c672fa
Diffstat (limited to 'android_icu4j')
-rw-r--r--android_icu4j/libcore_bridge/src/java/com/android/icu/text/ExtendedTimeZoneNames.java9
-rw-r--r--android_icu4j/libcore_bridge/src/java/com/android/icu/util/ExtendedTimeZone.java3
2 files changed, 7 insertions, 5 deletions
diff --git a/android_icu4j/libcore_bridge/src/java/com/android/icu/util/ExtendedTimeZone.java b/android_icu4j/libcore_bridge/src/java/com/android/icu/util/ExtendedTimeZone.java
index 5c2f3e55e..aaa856393 100644
--- a/android_icu4j/libcore_bridge/src/java/com/android/icu/util/ExtendedTimeZone.java
+++ b/android_icu4j/libcore_bridge/src/java/com/android/icu/util/ExtendedTimeZone.java
@@ -101,7 +101,8 @@ public class ExtendedTimeZone {
/**
* Returns a {@link ZoneRules} instance for this time zone.
*
- * @throws ZoneRulesException if the zone rules can't be created.
+ * @throws ZoneRulesException if the internal rules can't be parsed correctly, or it's not
+ * implemented for the subtype of {@link TimeZone}.
*
* @implNote This implementations relies on {@link BasicTimeZone#getTimeZoneRules()} in the
* following way:
diff --git a/android_icu4j/libcore_bridge/src/java/com/android/icu/text/ExtendedTimeZoneNames.java b/android_icu4j/libcore_bridge/src/java/com/android/icu/text/ExtendedTimeZoneNames.java
index 38f8ce671..57c7367bc 100644
--- a/android_icu4j/libcore_bridge/src/java/com/android/icu/text/ExtendedTimeZoneNames.java
+++ b/android_icu4j/libcore_bridge/src/java/com/android/icu/text/ExtendedTimeZoneNames.java
@@ -94,7 +94,8 @@ public class ExtendedTimeZoneNames {
}
/**
- * Returns true if the matched name is a display name for daylight saving time.
+ * Returns true if the matched name is a display name for daylight saving time. For example,
+ * returns true for "Pacific Daylight Time", but false for "Pacific Standard Time".
*
* @hide
*/
@@ -143,7 +144,7 @@ public class ExtendedTimeZoneNames {
* is US, America/Los_Angeles is returned.</li>
* </ul>
*
* @param s input string to be matched against time zone names in ICU
* @param start the begin index in the CharSequence {@code s}
* @param currentTzId the time zone ID prioritized to be matched if multiple time zone IDs can
* be matched and this is one of the matched IDs.
@@ -152,12 +153,12 @@ public class ExtendedTimeZoneNames {
* @hide
*/
@IntraCoreApi
- public @Nullable MatchedTimeZone matchName(@NonNull CharSequence s, int start,
+ public @Nullable MatchedTimeZone matchName(@NonNull CharSequence text, int start,
@NonNull String currentTzId) {
currentTzId = TimeZone.getCanonicalID(currentTzId);
Collection<TimeZoneNames.MatchInfo> matchedInfos =
- timeZoneNames.find(s, start, STANDARD_AND_DST_TYPES);
+ timeZoneNames.find(text, start, STANDARD_AND_DST_TYPES);
if (matchedInfos.isEmpty()) {
return null;
@@ -143,7 +144,7 @@ public class ExtendedTimeZoneNames {
* </ul>
*
- * @param s input string to be matched against time zone names in ICU
+ * @param text input string to be matched against time zone names in ICU
* @param start the begin index in the CharSequence {@code s}
* @param currentTzId the time zone ID prioritized to be matched if multiple time zone IDs can